# -*- coding: utf-8 -*-

"""
Simple boilerplate to create matplotlib-powered QT application.
The hard part here is to understand how blit works.
"""

import matplotlib
import matplotlib.pylab as plt
from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
from matplotlib.backends.backend_qt4agg import NavigationToolbar2QT as NavigationToolbar
from matplotlib.figure import Figure

from PyQt4.QtCore import *
from PyQt4.QtGui import *

import numpy as np

class SliderApp(QMainWindow):

    def __init__(self, parent=None, dpi=100, figsize=(12, 12)):
        QMainWindow.__init__(self, parent)
        self.dpi = dpi
        self.figsize = figsize

        self.create_ui()
        self.initialize_app()
        self.canvas.draw()
        self.background = self.canvas.copy_from_bbox(self.fig.bbox)
        self.on_draw()

    def initialize_app(self):
        raise NotImplementedError("You need to provide your own initialize_app.")

    def update_plots(self):
        raise NotImplementedError("You need to provide your own update_plots.")

    def on_draw(self):
        """Update data according to slider positions."""
        self.canvas.restore_region(self.background)
        self.update_plots()
        self.canvas.blit(self.fig.bbox)

    def create_ui(self):
        self.main = QWidget()

        # Create mpl stuff
        self.fig = Figure(figsize=self.figsize, dpi=self.dpi, facecolor='#edecec')
        self.canvas = FigureCanvas(self.fig)
        self.canvas.setParent(self.main)

        self.mpl_toolbar = NavigationToolbar(self.canvas, self.main)
        #self.mpl_toolbar.setStyleSheet("background-color: #edecec")

        # Create sliders
        sliderLayout = QVBoxLayout()
        self.sliders = []
        for i in range(3):
            layout = QVBoxLayout()
            slider_label = QLabel('Slider %i' % i)
            slider = QSlider(Qt.Horizontal)
            slider.setRange(1, 30)
            self.connect(slider, SIGNAL('valueChanged(int)'), self.on_draw)
            slider.setMinimumSize(100, 1)
            layout.addWidget(slider_label)
            layout.addWidget(slider)
            sliderLayout.addLayout(layout)
            self.sliders.append(slider)

        spacer = QSpacerItem(100,100,QSizePolicy.Expanding,QSizePolicy.Expanding)
        sliderLayout.addItem(spacer)

        hbox = QHBoxLayout()
        hbox.addLayout(sliderLayout)
        hbox.addWidget(self.canvas)

        vbox = QVBoxLayout()
        vbox.addWidget(self.mpl_toolbar)
        vbox.addLayout(hbox)

        # Create "main" layout
        self.main.setLayout(vbox)
        self.setCentralWidget(self.main)
        self.showMaximized()



# -*- coding: utf-8 -*-
"""
Created on Sat Aug 30 15:14:18 2014

@author: jukka

SliderApp demo. Update data based on slider positions which are saved to
self.sliders[n].value(), where n = slider number.

"""

import sys
from PyQt4.QtGui import QApplication
from mplgbw.fancysliders import SliderApp
import numpy as np

class MyApp(SliderApp):

    def initialize_app(self):
        """Create 4 x 4 grid of plots and 3 line plots for each subplot."""

        # Create axes
        self.ax = np.zeros((4, 4), dtype=object)
        self.plots = np.zeros((4, 4, 3), dtype=object)
        plot_num = 1
        for i in range(4):
            for j in range(4):
                ax = self.ax[i, j] = self.fig.add_subplot(4, 4, plot_num)
                ax.tick_params(axis='both', which='major', labelsize=6)
                ax.tick_params(axis='both', which='minor', labelsize=6)
                ax.set_xlim(0, 10)
                ax.set_ylim(-10, 10)
                for k in range(3):
                    self.plots[i, j, k], = ax.plot([], [], animated=True)
                plot_num += 1

        self.fig.subplots_adjust(wspace=0.2, hspace=0.2)
        self.fig.tight_layout()

    def update_plots(self):
        """When sliders are moved, update data to plots."""
        x = np.linspace(0, 10, 20)
        for i in range(4):
            for j in range(4):
                for k in range(3):
                    y = np.sin(i*x*self.sliders[k].value() + j) + k + self.sliders[k].value()/10.0
                    self.plots[i, j, k].set_data(x, y)
                    self.ax[i, j].draw_artist(self.plots[i, j, k])

def main():
    app = QApplication(sys.argv)
    form = MyApp()
    form.show()
    app.exec_()


if __name__ == "__main__":
    main()


from setuptools import setup

setup(
    name='mplgbw',
    version='0.1',
    packages=['mplgbw',],
    license='FreeBSD',
    url='https://bitbucket.org/ahojukka5/mplgbw',
    author='Jukka Aho',
    author_email='ahojukka5@gmail.com',
    long_description=open('README.txt').read(),
)
